@@ -862,7 +862,7 @@ void HistoryView::mouseDoubleClickEvent(QMouseEvent *e) {
 					int i1 = str.left(index).toInt();
 					int i2 = str.mid(index + 1).toInt();
 					if(i1 >= 0 && i1 < (int) settings->v_result.size() && i2 < (int) settings->v_result[i1].size()) {
-						emit insertTextRequested(settings->v_result[i1][settings->v_result[i1].size() - i2 - 1]);
+						emit insertTextRequested(settings->replaceResultSeparators(settings->v_result[i1][settings->v_result[i1].size() - i2 - 1]));
 					}
 				}
 			} else if(str[0] == '#') {
@@ -882,7 +882,7 @@ void HistoryView::mouseDoubleClickEvent(QMouseEvent *e) {
 					int i2 = str.mid(index + 1).toInt();
 					if(i1 >= 0 && (size_t) i1 < settings->v_result.size() && i2 >= 0 && (size_t) i2 < settings->v_result[i1].size()) {
 						if(!settings->v_result[i1][i2].empty() && settings->v_result[i1][i2][0] == '#') editComment(i1, i2);
-						else emit insertTextRequested(settings->v_result[i1][i2]);
+						else emit insertTextRequested(settings->replaceResultSeparators(settings->v_result[i1][i2]));
 					}
 				}
 			}
