@@ -328,10 +328,21 @@ void KeypadWidget::createKeypad(int i) {
 		connect(menu, SIGNAL(aboutToShow()), this, SLOT(updateFactorizeMenu()));
 
 		c++;
-		SYMBOL_BUTTON2("%", "‰", c, 1);
-		button->setToolTip(tr("Percent or remainder"), QString::fromStdString(CALCULATOR->getVariableById(VARIABLE_ID_PERMILLE)->title(true, settings->printops.use_unicode_signs)));
-		CREATE_MENU
-		connect(menu, SIGNAL(aboutToShow()), this, SLOT(updatePercentageMenu()));
+		if(!settings->show_percent_in_numpad) {
+			SYMBOL_BUTTON2("%", "‰", c, 1);
+			button->setToolTip(tr("Percent or remainder"), QString::fromStdString(CALCULATOR->getVariableById(VARIABLE_ID_PERMILLE)->title(true, settings->printops.use_unicode_signs)));
+			CREATE_MENU
+			connect(menu, SIGNAL(aboutToShow()), this, SLOT(updatePercentageMenu()));
+			percentButton = button;
+		} else {
+			button = new KeypadButton("(x)", this);
+			button->setToolTip(tr("Smart parentheses"), tr("Vector brackets"));
+			connect(button, SIGNAL(clicked()), this, SIGNAL(parenthesesClicked()));
+			connect(button, SIGNAL(clicked2()), this, SIGNAL(bracketsClicked()));
+			connect(button, SIGNAL(clicked3()), this, SIGNAL(bracketsClicked()));
+			grid->addWidget(button, c, 2, 1, 1);
+			parButton = button;
+		}
 		SYMBOL_ITEM2_BUTTON("±", CALCULATOR->getFunctionById(FUNCTION_ID_UNCERTAINTY), CALCULATOR->getFunctionById(FUNCTION_ID_INTERVAL), c, 0);
 		button->setToolTip(tr("Uncertainty/interval"), tr("Relative error"), tr("Interval"));
 		CREATE_MENU
@@ -347,7 +358,7 @@ void KeypadWidget::createKeypad(int i) {
 		connect(button, SIGNAL(clicked()), this, SLOT(onItemButtonClicked()));
 		connect(button, SIGNAL(clicked2()), this, SLOT(onUnitButtonClicked2()));
 		connect(button, SIGNAL(clicked3()), this, SLOT(onUnitButtonClicked3()));
-		grid->addWidget(button, c, 2, 1, 1);
+		grid->addWidget(button, c, settings->show_percent_in_numpad ? 1 : 2, 1, 1);
 		unitButton = button;
 		unitButton->setToolTip(QString::fromStdString(u ? u->title(true, settings->printops.use_unicode_signs) : sunit), p1 ? QString::fromStdString(p1->longName()) : QString(), p2 ? QString::fromStdString(p2->longName()) : QString());
 		CREATE_MENU
@@ -517,6 +528,59 @@ void KeypadWidget::createKeypad(int i) {
 		createNumpad(keypadN, 1);
 	}
 }
+void KeypadWidget::updateButtonLocation() {
+	KeypadButton *button, *prev_parbutton = parButton;
+	QMenu *menu;
+	if(settings->show_percent_in_numpad) {
+		 if(percentButton && keypadG->layout()) {
+			QGridLayout *grid = (QGridLayout*) keypadG->layout();
+			percentButton->deleteLater();
+			percentButton = NULL;
+			button = new KeypadButton("(x)", this);
+			button->setToolTip(tr("Smart parentheses"), tr("Vector brackets"));
+			connect(button, SIGNAL(clicked()), this, SIGNAL(parenthesesClicked()));
+			connect(button, SIGNAL(clicked2()), this, SIGNAL(bracketsClicked()));
+			connect(button, SIGNAL(clicked3()), this, SIGNAL(bracketsClicked()));
+			grid->removeWidget(unitButton);
+			grid->addWidget(button, 4, 2, 1, 1);
+			grid->addWidget(unitButton, 4, 1, 1, 1);
+			parButton = button;
+		}
+		if(prev_parbutton && (settings->hide_numpad ? keypadN->layout() : numpad->layout())) {
+			QGridLayout *grid = (QGridLayout*) (settings->hide_numpad ? keypadN->layout() : numpad->layout());
+			prev_parbutton->deleteLater();
+			if(parButton == prev_parbutton) parButton = NULL;
+			SYMBOL_BUTTON2("%", "‰", 0, 0);
+			button->setToolTip(tr("Percent or remainder"), QString::fromStdString(CALCULATOR->getVariableById(VARIABLE_ID_PERMILLE)->title(true, settings->printops.use_unicode_signs)));
+			percentButton = button;
+		}
+	} else {
+		if(percentButton && (settings->hide_numpad ? keypadN->layout() : numpad->layout())) {
+			QGridLayout *grid = (QGridLayout*) (settings->hide_numpad ? keypadN->layout() : numpad->layout());
+			percentButton->deleteLater();
+			percentButton = NULL;
+			button = new KeypadButton("(x)", this);
+			button->setToolTip(tr("Smart parentheses"), tr("Vector brackets"));
+			connect(button, SIGNAL(clicked()), this, SIGNAL(parenthesesClicked()));
+			connect(button, SIGNAL(clicked2()), this, SIGNAL(bracketsClicked()));
+			connect(button, SIGNAL(clicked3()), this, SIGNAL(bracketsClicked()));
+			grid->addWidget(button, 0, 0, 1, 1);
+			parButton = button;
+		}
+		if(prev_parbutton && keypadG->layout()) {
+			QGridLayout *grid = (QGridLayout*) keypadG->layout();
+			prev_parbutton->deleteLater();
+			if(parButton == prev_parbutton) parButton = NULL;
+			grid->removeWidget(unitButton);
+			SYMBOL_BUTTON2("%", "‰", 4, 1);
+			grid->addWidget(unitButton, 4, 2, 1, 1);
+			button->setToolTip(tr("Percent or remainder"), QString::fromStdString(CALCULATOR->getVariableById(VARIABLE_ID_PERMILLE)->title(true, settings->printops.use_unicode_signs)));
+			CREATE_MENU
+			connect(menu, SIGNAL(aboutToShow()), this, SLOT(updatePercentageMenu()));
+			percentButton = button;
+		}
+	}
+}
 void KeypadWidget::createNumpad(QWidget *w, int i) {
 	if(acButton[i]) return;
 	KeypadButton *button;
@@ -528,12 +592,19 @@ void KeypadWidget::createNumpad(QWidget *w, int i) {
 	button->setToolTip(tr("Left parenthesis"), tr("Left vector bracket"));
 	SYMBOL_BUTTON2(")", "]", 2, c)
 	button->setToolTip(tr("Right parenthesis"), tr("Right vector bracket"));
-	button = new KeypadButton("(x)", this);
-	button->setToolTip(tr("Smart parentheses"), tr("Vector brackets"));
-	connect(button, SIGNAL(clicked()), this, SIGNAL(parenthesesClicked()));
-	connect(button, SIGNAL(clicked2()), this, SIGNAL(bracketsClicked()));
-	connect(button, SIGNAL(clicked3()), this, SIGNAL(bracketsClicked()));
-	grid->addWidget(button, 0, c, 1, 1);
+	if(settings->show_percent_in_numpad) {
+		SYMBOL_BUTTON2("%", "‰", 0, c);
+		button->setToolTip(tr("Percent or remainder"), QString::fromStdString(CALCULATOR->getVariableById(VARIABLE_ID_PERMILLE)->title(true, settings->printops.use_unicode_signs)));
+		percentButton = button;
+	} else {
+		button = new KeypadButton("(x)", this);
+		button->setToolTip(tr("Smart parentheses"), tr("Vector brackets"));
+		connect(button, SIGNAL(clicked()), this, SIGNAL(parenthesesClicked()));
+		connect(button, SIGNAL(clicked2()), this, SIGNAL(bracketsClicked()));
+		connect(button, SIGNAL(clicked3()), this, SIGNAL(bracketsClicked()));
+		grid->addWidget(button, 0, c, 1, 1);
+		parButton = button;
+	}
 	SYMBOL_BUTTON3(QString::fromStdString(CALCULATOR->getComma()), " ", "\n", 3, c)
 	button->setToolTip(tr("Argument separator"), tr("Blank space"), tr("New line"));
 	commaButton[i] = button;
@@ -590,7 +661,8 @@ void KeypadWidget::createNumpad(QWidget *w, int i) {
 	OPERATOR_BUTTON3(settings->multiplicationSign(), "&", "<<", 1, c);
 	button->setToolTip(tr("Multiplication"), tr("Bitwise AND"), tr("Bitwise Shift"));
 	multiplicationButton[i] = button;
-	button = new KeypadButton(LOAD_ICON("edit-delete"), this, true);
+	// Standard calculator button. Do not use more than three characters.
+	button = new KeypadButton(tr("DEL"), this, true);
 	connect(button, SIGNAL(clicked()), this, SIGNAL(delClicked()));
 	connect(button, SIGNAL(clicked2()), this, SIGNAL(backspaceClicked()));
 	connect(button, SIGNAL(clicked3()), this, SIGNAL(backspaceClicked()));
@@ -686,6 +758,8 @@ KeypadWidget::KeypadWidget(QWidget *parent) : QWidget(parent) {
 	customOKButton = NULL;
 	customEditButton = NULL;
 	xButton = NULL;
+	percentButton = NULL;
+	parButton = NULL;
 
 	updateStretch();
 
@@ -1243,7 +1317,7 @@ void KeypadWidget::removeCustomRow() {
 	for(int c = 0; c < settings->custom_button_columns; c++) {
 		for(size_t i = settings->custom_buttons.size(); i > 0; i--) {
 			if(settings->custom_buttons[i - 1].r == r + 1 && settings->custom_buttons[i - 1].c == c + 1) {
-				settings->custom_buttons.erase(settings->custom_buttons.begin() + i);
+				settings->custom_buttons.erase(settings->custom_buttons.begin() + (i - 1));
 				break;
 			}
 		}
@@ -1262,7 +1336,7 @@ void KeypadWidget::removeCustomColumn() {
 	for(int r = 0; r < settings->custom_button_rows; r++) {
 		for(size_t i = settings->custom_buttons.size(); i > 0; i--) {
 			if(settings->custom_buttons[i - 1].r == r + 1 && settings->custom_buttons[i - 1].c == c + 1) {
-				settings->custom_buttons.erase(settings->custom_buttons.begin() + i);
+				settings->custom_buttons.erase(settings->custom_buttons.begin() + (i - 1));
 				break;
 			}
 		}
@@ -1555,7 +1629,6 @@ void KeypadWidget::changeEvent(QEvent *e) {
 		for(size_t i = 0; i < 2; i++) {
 			if(!acButton[i]) continue;
 			acButton[i]->setIcon(LOAD_ICON("edit-clear"));
-			delButton[i]->setIcon(LOAD_ICON("edit-delete"));
 		}
 		if(backButton) backButton->setIcon(LOAD_ICON("go-back"));
 		if(forwardButton) forwardButton->setIcon(LOAD_ICON("go-forward"));
