@@ -94,7 +94,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem("Русский");
 	combo->addItem("Slovenščina");
 	combo->addItem("Svenska");
-	combo->addItem("汉语");
+	combo->addItem("简体中文");
+	combo->addItem("繁體中文");
 	QString lang = settings->custom_lang.left(2);
 	if(lang == "ca") combo->setCurrentIndex(1);
 	else if(lang == "de") combo->setCurrentIndex(2);
@@ -108,7 +109,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	else if(lang == "ru") combo->setCurrentIndex(10);
 	else if(lang == "sl") combo->setCurrentIndex(11);
 	else if(lang == "sv") combo->setCurrentIndex(12);
-	else if(lang == "zh") combo->setCurrentIndex(13);
+	else if(settings->custom_lang == "zh_CN") combo->setCurrentIndex(13);
+	else if(settings->custom_lang == "zh_TW") combo->setCurrentIndex(14);
 	else combo->setCurrentIndex(0);
 	combo->setEnabled(!settings->ignore_locale);
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(langChanged(int)));
@@ -294,10 +296,18 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	decimalCommaBox = box;
 	BOX(tr("Ignore comma in numbers"), settings->evalops.parse_options.comma_as_separator, ignoreCommaToggled(bool)); ignoreCommaBox = box;
 	BOX(tr("Ignore dots in numbers"), settings->evalops.parse_options.dot_as_separator, ignoreDotToggled(bool)); ignoreDotBox = box;
-	BOX(tr("Indicate repeating decimals"), settings->printops.indicate_infinite_series, repeatingDecimalsToggled(bool));
 	if(CALCULATOR->getDecimalPoint() == COMMA) ignoreCommaBox->hide();
 	if(CALCULATOR->getDecimalPoint() == DOT) ignoreDotBox->hide();
 	BOX(tr("Copy unformatted ASCII by default"), settings->copy_ascii, copyAsciiToggled(bool));
+	BOX(tr("Place percent button in number pad"), settings->show_percent_in_numpad, showPercentInNumpadToggled(bool));
+	l->addWidget(new QLabel(tr("Indicate repeating decimals:"), this), r, 0);
+	combo = new QComboBox(this);
+	combo->addItem(tr("Off"), REPEATING_DECIMALS_OFF);
+	combo->addItem(tr("Ellipsis"), REPEATING_DECIMALS_ELLIPSIS);
+	combo->addItem(tr("Overline"), REPEATING_DECIMALS_OVERLINE);
+	combo->setCurrentIndex(combo->findData(settings->printops.indicate_infinite_series));
+	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(repeatingDecimalsChanged(int)));
+	l->addWidget(combo, r, 1); r++;
 	l->addWidget(new QLabel(tr("Digit grouping:"), this), r, 0);
 	combo = new QComboBox(this);
 	combo->addItem(tr("None"), DIGIT_GROUPING_NONE);
@@ -449,6 +459,7 @@ void PreferencesDialog::langChanged(int i) {
 		case 11: {settings->custom_lang = "sl_SL"; break;}
 		case 12: {settings->custom_lang = "sv_SE"; break;}
 		case 13: {settings->custom_lang = "zh_CN"; break;}
+		case 14: {settings->custom_lang = "zh_TW"; break;}
 	}
 	if(!settings->custom_lang.isEmpty()) {
 		ignoreLocaleBox->setChecked(false);
@@ -683,13 +694,17 @@ void PreferencesDialog::roundingChanged(int i) {
 	settings->printops.rounding = (RoundingMode) qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
 	emit resultFormatUpdated();
 }
-void PreferencesDialog::repeatingDecimalsToggled(bool b) {
-	settings->printops.indicate_infinite_series = b;
-	emit resultFormatUpdated();
+void PreferencesDialog::repeatingDecimalsChanged(int i) {
+	settings->printops.indicate_infinite_series = qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
+	emit resultDisplayUpdated();
 }
 void PreferencesDialog::copyAsciiToggled(bool b) {
 	settings->copy_ascii = b;
 }
+void PreferencesDialog::showPercentInNumpadToggled(bool b) {
+	settings->show_percent_in_numpad = b;
+	emit buttonLocationChanged();
+}
 void PreferencesDialog::copyAsciiWithoutUnitsToggled(bool b) {
 	settings->copy_ascii_without_units = b;
 }
@@ -742,7 +757,37 @@ void PreferencesDialog::updateVariableUnits() {
 }
 void PreferencesDialog::groupingChanged(int i) {
 	settings->printops.digit_grouping = (DigitGrouping) qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
-	emit resultFormatUpdated();
+	if(settings->printops.digit_grouping == DIGIT_GROUPING_LOCALE && (!settings->evalops.parse_options.comma_as_separator || CALCULATOR->getDecimalPoint() == COMMA) && CALCULATOR->local_digit_group_separator == COMMA) {
+		if(CALCULATOR->getDecimalPoint() == COMMA) {
+			settings->evalops.parse_options.comma_as_separator = true;
+			settings->evalops.parse_options.dot_as_separator = false;
+			ignoreCommaBox->blockSignals(true);
+			ignoreCommaBox->setChecked(true);
+			ignoreCommaBox->blockSignals(false);
+			ignoreDotBox->blockSignals(true);
+			ignoreDotBox->setChecked(false);
+			ignoreDotBox->blockSignals(false);
+			decimalCommaBox->toggle();
+		} else {
+			ignoreCommaBox->toggle();
+		}
+	} else if(settings->printops.digit_grouping == DIGIT_GROUPING_LOCALE && (!settings->evalops.parse_options.dot_as_separator || CALCULATOR->getDecimalPoint() == DOT) && CALCULATOR->local_digit_group_separator == DOT) {
+		if(CALCULATOR->getDecimalPoint() == DOT) {
+			settings->evalops.parse_options.dot_as_separator = true;
+			settings->evalops.parse_options.comma_as_separator = false;
+			ignoreDotBox->blockSignals(true);
+			ignoreDotBox->setChecked(true);
+			ignoreDotBox->blockSignals(false);
+			ignoreCommaBox->blockSignals(true);
+			ignoreCommaBox->setChecked(false);
+			ignoreCommaBox->blockSignals(false);
+			decimalCommaBox->toggle();
+		} else {
+			ignoreDotBox->toggle();
+		}
+	} else {
+		emit resultFormatUpdated();
+	}
 }
 void PreferencesDialog::intervalDisplayChanged(int i) {
 	if(i == 0) {
